# coding:utf-8


class _const:
    class ConstError(TypeError):
        pass

    class ConstCaseError(ConstError):
        pass

    def __setattr__(self, name, value):
        if name in self.__dict__:
            raise self.ConstError("can't change const %s" % name)
        if not name.isupper():
            raise self.ConstCaseError('const name "%s" is not all uppercase' % name)
        self.__dict__[name] = value


constant = _const()

constant.USER_PROFILE_DOES_NOT_EXIST = '用户概要信息不存在'
constant.USER_DOES_NOT_EXIST = '用户不存在'

constant.USER_OR_PASSWORD_DOES_NOT_CORRECT = '手机号或密码错误'
constant.IDENTIFICATION_IS_REQUIRED = '手机号不能为空。'
constant.PASSWORD_IS_REQUIRED = '密码不能为空'

constant.NO_ASSET_SUMMARY_WAS_FOUND = '资产概要信息不存在。'
constant.NO_ASSETS_WAS_FOUND = '资产信息不存在。'
constant.NO_CURRENCIES_WERE_FOUND = '货币不存在。'
constant.NO_EARNINGS_WAS_FOUND = '收益不存在。'



class AuthException(Exception):
    def __init__(self, err='数据库错误'):
        Exception.__init__(self, err)


class AuthorizationError(Exception):
    def __init__(self, err='Authorize error'):
        Exception.__init__(self, err)



import datetime
from datetime import datetime as dt


def init_end_date():
    return datetime.datetime.now().strftime("%Y-%m-%d")


def init_start_end():
    return (datetime.datetime.now() - datetime.timedelta(days=30)).strftime("%Y-%m-%d")


def add_days(days, date):
    return dt.strftime(dt.strptime(date, "%Y-%m-%d") + datetime.timedelta(days=days), "%Y-%m-%d")



import json


def build(response, is_success=True, description=''):
    data = None
    if response:
        data = response.to_resource()

    resource = json.dumps({
        "success": is_success,
        "description": description,
        "data": data
    }, indent=4, sort_keys=True, default=str)
    return json.loads(resource)



import subprocess

subprocess.run("flake8", shell=True, check=True)
subprocess.run("pipenv run py.test", shell=True, check=True)
subprocess.run("nohup pipenv run python application.py --active_profile=apitest  > nohup.log 2>&1 &", shell=True,
               check=True)
subprocess.run("newman run tests/api_tests/assets-center-apis-tests.postman_collection.json", shell=True, check=True)

subprocess.run("rm -rf nohup.out", shell=True, check=True)
subprocess.run("rm -rf nohup.log", shell=True, check=True)





try:  # for pip >= 10
    from pip._internal.req import parse_requirements
except ImportError:  # for pip <= 9.0.3
    from pip.req import parse_requirements
from setuptools import setup, find_packages

install_reqs = parse_requirements('requirements.txt', session=False)


reqs = [str(ir.req) for ir in install_reqs]

setup(
    name='nifeng-data-store',  # Required

    version='1.0.4',  # Required

    description='A simple data store project',  # Required    

    author='Nifeng',  # Optional

    author_email='tao.xu@freecoinx.com',  # Optional
    packages=find_packages(),
    install_requires=reqs
)
